@@ -68,7 +68,7 @@ C<List> is the dynamic object array that has a specified object array type.
 
 =head2 DEFAULT_CAPACITY
 
-The default capacity. The value is C<4>.
+The default capacity. The value is 4.
 
 =head1 Fields
 
@@ -98,7 +98,7 @@ The values. This is the elements in the internally used array, but it can be man
 
 Creates a new C<List> object using L</"new_len">.
 
-The passed length to L</"new_len"> is the length of the $array. If the array is C<undef>, the length is C<0>.
+The passed length to L</"new_len"> is the length of the $array. If the array is undef, the length is 0.
 
 The element's addresses of the object array are copied to the values of the the created array.
   
@@ -116,13 +116,13 @@ Creates a new C<StringList> object with the $protot_array, the $length and the $
 
 If the $protot_array is undefined, the $protot_array is set to an C<object[]> object.
 
-If the $capacity is less than C<0>, the $capacity is set to the value of L</"DEFAULT_CAPACITY">.
+If the $capacity is less than 0, the $capacity is set to the value of L</"DEFAULT_CAPACITY">.
 
 If the $length is greater than the $capacity, the $capacity is set to the length.
 
 Exceptions:
 
-The $length must be greater than or equal to C<0>.
+The $length must be greater than or equal to 0. Otherwize an exception is thrown.
 
 Examples:
 
@@ -139,9 +139,9 @@ Gets the element of the position of the $index.
 
 Exceptions:
 
-The $index must be greater than or equal to C<0>.
+The $index must be greater than or equal to 0. Otherwize an exception is thrown.
 
-The $index must be less than the length of the $list.
+The $index must be less than the length of the $list. Otherwize an exception is thrown.
 
 =head2 insert
 
@@ -151,9 +151,9 @@ Inserts an $element to the position of the $index.
 
 Exceptions:
 
-The $index must be greater than or equal to C<0>.
+The $index must be greater than or equal to 0. Otherwize an exception is thrown.
 
-The $index must be less than or equal to the length of the $list.
+The $index must be less than or equal to the length of the $list. Otherwize an exception is thrown.
 
 =head2 pop
 
@@ -163,7 +163,7 @@ Removes the last element and return it.
 
 Exceptions:
 
-The length of the $list must be greater than C<0>.
+The length of the $list must be greater than 0. Otherwize an exception is thrown.
             
 =head2 push
   
@@ -179,9 +179,9 @@ Removes the element at the position of the $index and return it.
 
 Exceptions:
 
-The $index must be greater than or equal to C<0>.
+The $index must be greater than or equal to 0. Otherwize an exception is thrown.
 
-The $index must be less than the length of the $list.
+The $index must be less than the length of the $list. Otherwize an exception is thrown.
 
 =head2 replace
 
@@ -191,11 +191,11 @@ Replaces the elements of the range specified by the $offset and the $lenght with
 
 Exceptions:
 
-The $offset must be greater than or equal to C<0>.
+The $offset must be greater than or equal to 0. Otherwize an exception is thrown.
 
-The $remove_length must be greater than or equal to C<0>.
+The $remove_length must be greater than or equal to 0. Otherwize an exception is thrown.
 
-The $offset + the $removing lenght must be less than or equal to the length of the $list.
+The $offset + the $removing lenght must be less than or equal to the length of the $list. Otherwize an exception is thrown.
 
 =head2 reserve
 
@@ -209,7 +209,7 @@ Note that L</"values"> is replaced with the new values and the values of the ori
 
 Exceptions:
 
-The $new_capacity must be greater than or equal to C<0>.
+The $new_capacity must be greater than or equal to 0. Otherwize an exception is thrown.
 
 =head2 resize
 
@@ -219,7 +219,7 @@ Resize the list with the $new_length.
 
 Exceptions:
 
-The $new_length must be greater than or equal to C<0>.
+The $new_length must be greater than or equal to 0. Otherwize an exception is thrown.
 
 =head2 replace
 
@@ -229,11 +229,11 @@ Replaces the elements of the range specified by the $offset and the $remove_leng
 
 Exceptions:
 
-The $offset must be greater than or equal to C<0>.
+The $offset must be greater than or equal to 0. Otherwize an exception is thrown.
 
-The $remove_length must be greater than or equal to C<0>.
+The $remove_length must be greater than or equal to 0. Otherwize an exception is thrown.
 
-The $offset + the $removing lenght must be less than or equal to the length of the $list.
+The $offset + the $removing lenght must be less than or equal to the length of the $list. Otherwize an exception is thrown.
 
 =head2 set
 
@@ -243,9 +243,9 @@ Sets the $element at the position of the $index.
 
 Exceptions:
 
-The $index must be greater than or equal to C<0>.
+The $index must be greater than or equal to 0. Otherwize an exception is thrown.
 
-The $index must be less than the length of the $list.
+The $index must be less than the length of the $list. Otherwize an exception is thrown.
 
 =head2 set_array
 
@@ -255,9 +255,9 @@ Sets an $array. Each element of the $array is copied to the element of the list.
 
 Exceptions:
 
-The $array must be defined.
+The $array must be defined. Otherwize an exception is thrown.
 
-The length of the $array must be the $same as the length of the $list.
+The length of the $array must be the $same as the length of the $list. Otherwize an exception is thrown.
 
 =head2 shift
 
@@ -267,7 +267,7 @@ Removes the first element and return it.
 
 Exceptions:
 
-The length of the $list must be greater than C<0>.
+The length of the $list must be greater than 0. Otherwize an exception is thrown.
 
 =head2 to_array
 
